@@ -64,7 +64,7 @@ A nice way to drive Win32 programs from a test script is to use OLE Automation
 where SendKeys comes handy.
 
 Some time ago Al Williams published a Delphi version in Dr. Dobb's
-(http://www.ddj.com/ddj/1997/careers1/wil2.htm). I ported it to C and
+(http://www.drdobbs.com/keys-to-the-kingdom/184410429). I ported it to C and
 packaged it using h2xs...
 
 The tentative name for this module is Win32::GuiTest (mostly because I plan to
@@ -242,7 +242,7 @@ require DynaLoader;
 }
 $EXPORT_TAGS{ALL}= \@EXPORT_OK;
                              
-$VERSION = '1.60';
+$VERSION = '1.61';
 
 $debug = 0;
 
@@ -1849,7 +1849,7 @@ Here are a few items where help would be welcome.
 
 The SendKeys function is based on the Delphi sourcecode
 published by Al Williams  E<lt>http://www.al-williams.com/awc/E<gt> 
-in Dr.Dobbs  E<lt>http://www.ddj.com/ddj/1997/careers1/wil2.htmE<gt>.
+in Dr.Dobbs  E<lt>http://www.drdobbs.com/keys-to-the-kingdom/184410429E<gt>.
 
 Copyright (c) 1998-2002 Ernesto Guisado, (c) 2004 Dennis K. Paulsen. All rights 
 reserved. This program is free software; You may distribute it and/or modify it
